@@ -13,9 +13,6 @@
 #
 # Copyright Buildbot Team Members
 
-from __future__ import absolute_import
-from __future__ import print_function
-
 import multiprocessing
 import os.path
 import socket
@@ -42,9 +39,21 @@ class UnknownCommand(pb.Error):
 
 
 class ProtocolCommandBase:
-    def __init__(self, unicode_encoding, worker_basedir, buffer_size, buffer_timeout,
-                 max_line_length, newline_re, builder_is_running, on_command_complete,
-                 on_lost_remote_step, command, command_id, args):
+    def __init__(
+        self,
+        unicode_encoding,
+        worker_basedir,
+        buffer_size,
+        buffer_timeout,
+        max_line_length,
+        newline_re,
+        builder_is_running,
+        on_command_complete,
+        on_lost_remote_step,
+        command,
+        command_id,
+        args,
+    ):
         self.unicode_encoding = unicode_encoding
         self.worker_basedir = worker_basedir
         self.buffer_size = buffer_size
@@ -61,26 +70,29 @@ class ProtocolCommandBase:
         try:
             factory = registry.getFactory(command)
         except KeyError:
-            raise UnknownCommand(u"(command {0}): unrecognized WorkerCommand '{1}'".format(
-                command_id, command))
+            raise UnknownCommand(
+                "(command {0}): unrecognized WorkerCommand '{1}'".format(command_id, command)
+            )
 
         # .command points to a WorkerCommand instance, and is set while the step is running.
         self.command = factory(self, command_id, args)
         self._lbfs = {}
-        self.buffer = buffer_manager.BufferManager(reactor, self.protocol_send_update_message,
-                                                   self.buffer_size, self.buffer_timeout)
+        self.buffer = buffer_manager.BufferManager(
+            reactor, self.protocol_send_update_message, self.buffer_size, self.buffer_timeout
+        )
 
         self.is_complete = False
 
     def log_msg(self, msg):
-        log.msg(u"(command {0}): {1}".format(self.command_id, msg))
+        log.msg("(command {0}): {1}".format(self.command_id, msg))
 
     def split_lines(self, stream, text, text_time):
         try:
             return self._lbfs[stream].append(text, text_time)
         except KeyError:
-            lbf = self._lbfs[stream] = lineboundaries.LineBoundaryFinder(self.max_line_length,
-                                                                         self.newline_re)
+            lbf = self._lbfs[stream] = lineboundaries.LineBoundaryFinder(
+                self.max_line_length, self.newline_re
+            )
             return lbf.append(text, text_time)
 
     def flush_command_output(self):
@@ -153,8 +165,8 @@ class WorkerForBuilderBase(service.Service):
 
 
 class BotBase(service.MultiService):
-
     """I represent the worker-side bot."""
+
     name = "bot"
     WorkerForBuilder = WorkerForBuilderBase
 
@@ -164,8 +176,7 @@ class BotBase(service.MultiService):
         service.MultiService.__init__(self)
         self.basedir = basedir
         self.numcpus = None
-        self.unicode_encoding = unicode_encoding or sys.getfilesystemencoding(
-        ) or 'ascii'
+        self.unicode_encoding = unicode_encoding or sys.getfilesystemencoding() or 'ascii'
         self.delete_leftover_dirs = delete_leftover_dirs
         self.builders = {}
         # Don't send any data until at least buffer_size bytes have been collected
@@ -184,10 +195,7 @@ class BotBase(service.MultiService):
         service.MultiService.startService(self)
 
     def remote_getCommands(self):
-        commands = {
-            n: base.command_version
-            for n in registry.getAllCommandNames()
-        }
+        commands = {n: base.command_version for n in registry.getAllCommandNames()}
         return commands
 
     def remote_print(self, message):
@@ -228,8 +236,7 @@ class BotBase(service.MultiService):
                         try:
                             files[f] = bytes2unicode(fin.read())
                         except UnicodeDecodeError:
-                            log.err(failure.Failure(),
-                                    'error while reading file: %s' % (filename))
+                            log.err(failure.Failure(), 'error while reading file: %s' % (filename))
 
         self._read_os_release(self.os_release_file, files)
 
@@ -237,8 +244,10 @@ class BotBase(service.MultiService):
             try:
                 self.numcpus = multiprocessing.cpu_count()
             except NotImplementedError:
-                log.msg("warning: could not detect the number of CPUs for "
-                        "this worker. Assuming 1 CPU.")
+                log.msg(
+                    "warning: could not detect the number of CPUs for "
+                    "this worker. Assuming 1 CPU."
+                )
                 self.numcpus = 1
         files['environ'] = os.environ.copy()
         files['system'] = os.name
@@ -264,16 +273,20 @@ class BotBase(service.MultiService):
 
 
 class WorkerBase(service.MultiService):
-
-    def __init__(self, name, basedir, bot_class,
-                 umask=None,
-                 unicode_encoding=None,
-                 delete_leftover_dirs=False):
-
+    def __init__(
+        self,
+        name,
+        basedir,
+        bot_class,
+        umask=None,
+        unicode_encoding=None,
+        delete_leftover_dirs=False,
+    ):
         service.MultiService.__init__(self)
         self.name = name
-        bot = bot_class(basedir, unicode_encoding=unicode_encoding,
-                       delete_leftover_dirs=delete_leftover_dirs)
+        bot = bot_class(
+            basedir, unicode_encoding=unicode_encoding, delete_leftover_dirs=delete_leftover_dirs
+        )
         bot.setServiceParent(self)
         self.bot = bot
         self.umask = umask
