@@ -16,10 +16,6 @@
 # N.B.: don't import anything that might pull in a reactor yet. Some of our
 # subcommands want to load modules that need the gtk reactor.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import re
 import sys
@@ -52,7 +48,8 @@ class MakerBase(usage.Options):
         # only set completion suggestion if running with
         # twisted version (>=11.1.0) that supports it
         compData = usage.Completions(
-            extraActions=[usage.CompleteDirs(descr="worker base directory")])
+            extraActions=[usage.CompleteDirs(descr="worker base directory")]
+        )
 
     opt_h = usage.Options.opt_help
 
@@ -102,38 +99,47 @@ class CreateWorkerOptions(MakerBase):
     subcommandFunction = "buildbot_worker.scripts.create_worker.createWorker"
     optFlags = [
         ["force", "f", "Re-use an existing directory"],
-        ["relocatable", "r",
-         "Create a relocatable buildbot.tac"],
-        ["no-logrotate", "n",
-         "Do not permit buildmaster rotate logs by itself"],
-        ['use-tls', None,
-         "Uses TLS to connect to master"],
-        ['delete-leftover-dirs', None,
-         'Delete folders that are not required by the master on connection'],
+        ["relocatable", "r", "Create a relocatable buildbot.tac"],
+        ["no-logrotate", "n", "Do not permit buildmaster rotate logs by itself"],
+        ['use-tls', None, "Uses TLS to connect to master"],
+        [
+            'delete-leftover-dirs',
+            None,
+            'Delete folders that are not required by the master on connection',
+        ],
     ]
     optParameters = [
-        ["keepalive", "k", 600,
-         "Interval at which keepalives should be sent (in seconds)"],
-        ["umask", None, "None",
-         "controls permissions of generated files. "
-         "Use --umask=0o22 to be world-readable"],
-        ["maxdelay", None, 300,
-         "Maximum time between connection attempts"],
-        ["maxretries", None, 'None',
-         "Maximum number of retries before worker shutdown"],
-        ["numcpus", None, "None",
-         "Number of available cpus to use on a build. "],
-        ["log-size", "s", "10000000",
-         "size at which to rotate twisted log files"],
-        ["log-count", "l", "10",
-         "limit the number of kept old twisted log files "
-         "(None for unlimited)"],
-        ["allow-shutdown", "a", None,
-         "Allows the worker to initiate a graceful shutdown. One of "
-         "'signal' or 'file'"],
+        ["keepalive", "k", 600, "Interval at which keepalives should be sent (in seconds)"],
+        [
+            "umask",
+            None,
+            "None",
+            "controls permissions of generated files. Use --umask=0o22 to be world-readable",
+        ],
+        ["maxdelay", None, 300, "Maximum time between connection attempts"],
+        ["maxretries", None, 'None', "Maximum number of retries before worker shutdown"],
+        ["numcpus", None, "None", "Number of available cpus to use on a build. "],
+        ["log-size", "s", "10000000", "size at which to rotate twisted log files"],
+        [
+            "log-count",
+            "l",
+            "10",
+            "limit the number of kept old twisted log files (None for unlimited)",
+        ],
+        [
+            "allow-shutdown",
+            "a",
+            None,
+            "Allows the worker to initiate a graceful shutdown. One of 'signal' or 'file'",
+        ],
         ["protocol", None, "pb", "Protocol to be used when creating master-worker connection"],
-        ["proxy-connection-string", None, None,
-         "Address of HTTP proxy to tunnel through"]
+        [
+            "connection-string",
+            None,
+            None,
+            "Twisted endpoint connection string (this will override master host[:port])",
+        ],
+        ["proxy-connection-string", None, None, "Address of HTTP proxy to tunnel through"],
     ]
 
     longdesc = textwrap.dedent("""
@@ -177,24 +183,27 @@ class CreateWorkerOptions(MakerBase):
             try:
                 master, port = master_arg.split(":")
             except ValueError:
-                raise usage.UsageError(("invalid <master> argument '{}', "
-                                        "if it is an ipv6 address, it must be enclosed by []"
-                                        ).format(master_arg))
+                raise usage.UsageError(
+                    (
+                        "invalid <master> argument '{}', "
+                        "if it is an ipv6 address, it must be enclosed by []"
+                    ).format(master_arg)
+                )
 
         if not master:
-            raise usage.UsageError("invalid <master> argument '{}'".format(
-                                   master_arg))
+            raise usage.UsageError("invalid <master> argument '{}'".format(master_arg))
         try:
             port = int(port)
         except ValueError:
-            raise usage.UsageError("invalid master port '{}', "
-                                   "needs to be a number".format(port))
+            raise usage.UsageError("invalid master port '{}', needs to be a number".format(port))
 
         return master, port
 
     def getSynopsis(self):
-        return "Usage:    buildbot-worker create-worker " \
+        return (
+            "Usage:    buildbot-worker create-worker "
             "[options] <basedir> <master> <name> <passwd>"
+        )
 
     def parseArgs(self, *args):
         if len(args) != 4:
@@ -213,18 +222,14 @@ class CreateWorkerOptions(MakerBase):
             try:
                 self[argument] = int(self[argument])
             except ValueError:
-                raise usage.UsageError("{} parameter needs to be a number".format(
-                                       argument))
+                raise usage.UsageError("{} parameter needs to be a number".format(argument))
 
         for argument in ["log-count", "maxretries", "umask", "numcpus"]:
-            if not re.match(r'^((0o)\d+|0|[1-9]\d*)$', self[argument]) and \
-                    self[argument] != 'None':
-                raise usage.UsageError("{} parameter needs to be a number"
-                                    " or None".format(argument))
+            if not re.match(r'^((0o)\d+|0|[1-9]\d*)$', self[argument]) and self[argument] != 'None':
+                raise usage.UsageError("{} parameter needs to be a number or None".format(argument))
 
         if self['allow-shutdown'] not in [None, 'signal', 'file']:
-            raise usage.UsageError("allow-shutdown needs to be one of"
-                                   " 'signal' or 'file'")
+            raise usage.UsageError("allow-shutdown needs to be one of 'signal' or 'file'")
 
 
 class Options(usage.Options):
@@ -232,16 +237,20 @@ class Options(usage.Options):
 
     subCommands = [
         # the following are all admin commands
-        ['create-worker', None, CreateWorkerOptions,
-         "Create and populate a directory for a new worker"],
+        [
+            'create-worker',
+            None,
+            CreateWorkerOptions,
+            "Create and populate a directory for a new worker",
+        ],
         ['start', None, StartOptions, "Start a worker"],
         ['stop', None, StopOptions, "Stop a worker"],
-        ['restart', None, RestartOptions,
-         "Restart a worker"],
+        ['restart', None, RestartOptions, "Restart a worker"],
     ]
 
     def opt_version(self):
         import buildbot_worker  # pylint: disable=import-outside-toplevel
+
         print("worker version: {}".format(buildbot_worker.version))
         usage.Options.opt_version(self)
 
